from mayan.apps.icons.icons import Icon

icon_document_duplicates_list = Icon(
    driver_name='fontawesome', symbol='clone'
)
icon_duplicated_document_list = Icon(
    driver_name='fontawesome', symbol='clone'
)
icon_duplicated_document_scan = Icon(
    driver_name='fontawesome-dual', primary_symbol='clone',
    secondary_symbol='eye'
)
