from mayan.apps.icons.icons import Icon

# App

icon_statistics = Icon(driver_name='fontawesome', symbol='chart-line')

# Statistic

icon_statistic_detail = Icon(driver_name='fontawesome', symbol='eye')
icon_statistic_queue = Icon(driver_name='fontawesome', symbol='cog')

# Statistic namespace

icon_statistic_namespace_detail = Icon(
    driver_name='fontawesome', symbol='chart-line'
)
icon_statistic_namespace_list = Icon(
    driver_name='fontawesome', symbol='chart-line'
)
