{% load i18n %}

{% load autoadmin_tags %}
{% load fundraiser_tags %}

{% autoadmin_properties %}

{# appearance_app_template_nocache #}

{% if autoadmin_properties.account %}
    {% fundraiser_message_fetch path='/locations/login/' as message %}

    {% if message %}
        <div class="row">
            <div class="col-xs-12 col-sm-10 col-sm-offset-1 col-md-10 col-md-offset-1 col-lg-6 col-lg-offset-3">
                <br>
                <div class="panel panel-primary">
                    <div class="panel-heading">
                        <h3 class="text-center panel-title">{{ message.title }}</h3>
                    </div>
                    <div class="panel-body">
                        <div class="content">
                            {{ message.body }}
                        </div>
                    </div>
                </div>
            </div>
        </div>
    {% endif %}
{% endif %}
