{% load static %}

<script src="{% static 'templating/node_modules/@highlightjs/cdn-assets/highlight.min.js' %}"></script>
<script src="{% static 'templating/node_modules/@highlightjs/cdn-assets/languages/django.min.js' %}"></script>
