{% load static %}

<link href="{% static 'mayan_forms/node_modules/dropzone/dist/dropzone.css' %}" media="screen" rel="stylesheet" type="text/css" />

<style>
    .dz-progress .dz-upload .progress-bar {
        width: 100%;
    }
    .dropzone .dz-preview.dz-success .dz-success-mark {
        -webkit-animation: slide-in 3s cubic-bezier(0.77, 0, 0.175, 1);
        -moz-animation: slide-in 3s cubic-bezier(0.77, 0, 0.175, 1);
        -ms-animation: slide-in 3s cubic-bezier(0.77, 0, 0.175, 1);
        -o-animation: slide-in 3s cubic-bezier(0.77, 0, 0.175, 1);
        animation: slide-in 3s cubic-bezier(0.77, 0, 0.175, 1);
        opacity: 1;
    }
</style>
