COMMAND_NAME_PLATFORMS_TEMPLATE = 'platforms_template'

DEFAULT_PLATFORMS_CLIENT_BACKEND_ARGUMENTS = {}
DEFAULT_PLATFORMS_CLIENT_BACKEND_ENABLED = ()
DEFAULT_SETTINGS_MODULE = 'mayan.settings.production'
