{% load static %}

<link href="{% static 'icons/node_modules/@fortawesome/fontawesome-free/css/all.min.css' %}" media="screen" rel="stylesheet" type="text/css" />
<link href="{% static 'icons/css/icons.css' %}" media="screen" rel="stylesheet" type="text/css" />
