DEFAULT_DIRECTORY_BASE = '/opt/'
DEFAULT_DIRECTORY_INSTALLATION = '/opt/mayan-edms/'
DEFAULT_DIRECTORY_MEDIA_ROOT = '/opt/mayan-edms/media/'
DEFAULT_DATABASE_NAME = 'mayan'
DEFAULT_DATABASE_PASSWORD = 'mayandbpass'
DEFAULT_DATABASE_USER = 'mayan'
DEFAULT_ELASTICSEARCH_PASSWORD = 'mayanespassword'
DEFAULT_OS_DISTRIBUTION = 'Debian 12'
DEFAULT_OS_GROUP = 'mayan'
DEFAULT_OS_USERNAME = 'mayan'
DEFAULT_RABBITMQ_CONSUMER_TIMEOUT = 1800000
DEFAULT_RABBITMQ_PASSWORD = 'mayanrabbitpass'
DEFAULT_RABBITMQ_USER = 'mayan'
DEFAULT_RABBITMQ_VHOST = 'mayan'
DEFAULT_REDIS_PASSWORD = 'mayanredispassword'
DEFAULT_SECRET_KEY = 'secret-key-missing!'
DEFAULT_USER_SETTINGS_FOLDER = 'user_settings/'
DEFAULT_USER_SETTINGS_MODULE = 'user_settings'
DJANGO_SERIES = '4.2'
DOCKER_HOST_REGISTRY_NAME = 'docker-registry.local'
DOCKER_HOST_REGISTRY_PORT = 5000
DOCKER_IMAGE_MAYAN_NAME = 'mayanedms/mayanedms'
DOCKER_IMAGE_MAYAN_TAG = 's4.10'
DOCKER_CLI_IMAGE_VERSION = 'docker:28.2.2-cli'
DOCKER_DIND_IMAGE_VERSION = 'docker:28.2.2-dind'
DOCKER_ELASTIC_IMAGE_NAME = 'elasticsearch'
DOCKER_ELASTIC_IMAGE_TAG = '9.1.3'
DOCKER_LINUX_IMAGE_NAME = 'debian'
DOCKER_LINUX_IMAGE_TAG = '12.11-slim'
DOCKER_MYSQL_IMAGE_NAME = 'mariadb'
DOCKER_MYSQL_IMAGE_TAG = '11.8.3'
DOCKER_ORACLE_IMAGE_VERSION = 'wnameless/oracle-xe-11g-r2'
DOCKER_POSTGRESQL_IMAGE_NAME = 'postgres'
DOCKER_POSTGRESQL_IMAGE_TAG = '15.14'
DOCKER_POSTGRESQL_MAX_CONNECTIONS = 150
DOCKER_PYTHON_IMAGE_VERSION = 'python:3.13.7-slim'
DOCKER_RABBITMQ_IMAGE_NAME = 'rabbitmq'
DOCKER_RABBITMQ_IMAGE_TAG = '4.1.4-management'
DOCKER_REDIS_IMAGE_NAME = 'redis'
DOCKER_REDIS_IMAGE_TAG = '7.4.5'
DOCKER_TRAEFIK_IMAGE_NAME = 'traefik'
DOCKER_TRAEFIK_IMAGE_TAG = 'v2.11.29'
DOCKER_USER_UID = 1000
DOCKER_USER_GID = 1000
FORGE_DOCKER_BASE_IMAGE_NAME = 'ubuntu'
FORGE_DOCKER_BASE_IMAGE_TAG = 'noble-20250910'
FORGE_DOCKER_COMPOSE_PROJECT_NAME = 'mayanforge'
FORGE_DOCKER_IMAGE_NAME = 'mayanedms/mayanforge'
FORGE_PYTHON_PACKAGES = 'setuptools==80.9.0 fancycompleter==0.11.1'
FORGE_PYTHON_VERSION = '3.13'
FORGE_TRANSIFEX_VERSION = 'v1.6.17'
GITLAB_CI_BRANCH_BUILDS_DOCKER = 'ci/builds/docker'
GITLAB_CI_BRANCH_BUILDS_DOCUMENTATION = 'ci/builds/documentation'
GITLAB_CI_BRANCH_BUILDS_PYTHON = 'ci/builds/python'
GITLAB_CI_BRANCH_DEPLOYMENTS_DEMO = 'ci/deployments/demo'
GITLAB_CI_BRANCH_DEPLOYMENTS_STAGING = 'ci/deployments/staging'
GITLAB_CI_BRANCH_RELEASES_ALL_MAJOR = 'ci/releases/all/major'
GITLAB_CI_BRANCH_RELEASES_ALL_MINOR = 'ci/releases/all/minor'
GITLAB_CI_BRANCH_RELEASES_DOCKER_MAJOR = 'ci/releases/docker/major'
GITLAB_CI_BRANCH_RELEASES_DOCKER_MINOR = 'ci/releases/docker/minor'
GITLAB_CI_BRANCH_RELEASES_DOCUMENTATION = 'ci/releases/documentation'
GITLAB_CI_BRANCH_RELEASES_NIGHTLY = 'ci/releases/nightly'
GITLAB_CI_BRANCH_RELEASES_PYTHON_MAJOR = 'ci/releases/python/major'
GITLAB_CI_BRANCH_RELEASES_PYTHON_MINOR = 'ci/releases/python/minor'
GITLAB_CI_BRANCH_RELEASES_STAGING = 'ci/releases/staging'
GITLAB_CI_BRANCH_RELEASES_TESTING = 'ci/releases/testing'
GITLAB_CI_BRANCH_TESTS_ALL = 'ci/tests/all'
GITLAB_CI_BRANCH_TESTS_DOCKER = 'ci/tests/docker'
GITLAB_CI_BRANCH_TESTS_PYTHON_ALL = 'ci/tests/python/all'
GITLAB_CI_BRANCH_TESTS_PYTHON_BASE = 'ci/tests/python/base'
GITLAB_CI_BRANCH_TESTS_PYTHON_UPGRADE = 'ci/tests/python/upgrade'
GITLAB_CI_BRANCH_TRY_STAGING = 'ci/try/staging'
GITLAB_CI_REMOTE_NAME = 'origin'
GUNICORN_LIMIT_REQUEST_LINE = 4094
GUNICORN_MAX_REQUESTS = 500
GUNICORN_REQUESTS_JITTER = 50
GUNICORN_TIMEOUT = 120
GUNICORN_WORKER_CLASS = 'gevent'
GUNICORN_WORKERS = 3
LINUX_PACKAGES_DEBIAN_BASE = 'ca-certificates clamav file fuse ghostscript git gnupg1 graphviz libarchive-zip-perl libfile-mimeinfo-perl libimage-exiftool-perl libmariadb3 libpq5 libreoffice-calc-nogui libreoffice-draw-nogui libreoffice-impress-nogui libreoffice-math-nogui libreoffice-writer-nogui poppler-utils sane-utils sudo supervisor tesseract-ocr'
LINUX_PACKAGES_DEBIAN_BUILD = 'g++ gcc libffi-dev libjpeg-dev libldap2-dev libpng-dev libsasl2-dev libssl-dev libtiff-dev make pkg-config zlib1g-dev'
LINUX_PACKAGES_DEBIAN_DOCUMENTATION = 'enchant-2 graphviz libcairo2'
LINUX_PACKAGES_DEBIAN_FORGE = 'bash-completion curl gettext less software-properties-common squid-deb-proxy-client vim virtualenvwrapper'
LINUX_PACKAGES_DEBIAN_MYSQL = 'default-libmysqlclient-dev'
LINUX_PACKAGES_DEBIAN_POSTGRESQL = 'libpq-dev'
LINUX_PACKAGES_DEBIAN_PUSH = 'openssh-client rsync'
LINUX_PACKAGES_DEBIAN_PYTHON = 'make python3-dev python3-venv'
LINUX_PACKAGES_DEBIAN_TEST = 'tesseract-ocr-deu'
LINUX_PACKAGES_ALPINE_BUILD = 'cairo gcc libffi-dev libjpeg-turbo-dev libmagic make musl-dev zlib-dev'
LINUX_PACKAGES_ALPINE_PYTHON = 'python3 python3-dev py3-packaging'
LOCAL_VERSION = ''
PYTHON_AMQP_VERSION = '5.3.1'
PYTHON_MYSQL_VERSION = '2.2.7'
PYTHON_ORACLE_VERSION = '8.1.0'
PYTHON_PIP_VERSION = '25.2'
PYTHON_PSYCOPG_VERSION = '3.2.9'
PYTHON_PSYCOPG_VERSION_PREVIOUS = '3.1.20'
PYTHON_PSUTIL_VERSION = '6.1.1'
PYTHON_REDIS_VERSION = '6.4.0'
PYTHON_SETUPTOOLS_VERSION = '80.9.0'
PYTHON_WHEEL_VERSION = '0.45.1'
SOURCE_CODE_REPOSITORY = 'https://gitlab.com/mayan-edms/mayan-edms/'
SOURCE_CODE_GIT = 'https://gitlab.com/mayan-edms/mayan-edms.git'
SOURCE_CODE_ISSUES = 'https://gitlab.com/mayan-edms/mayan-edms/issues/'
SECRET_KEY_FILENAME = 'SECRET_KEY'
SYSTEM_DIR = 'system'
SUPERVISOR_CONFIGURATION_DIRECTORY = '/etc/supervisor/conf.d/'
SUPERVISOR_CONFIGURATION_FILENAME = 'mayan-edms.conf'
MAYAN_WORKER_A_CONCURRENCY = 4
MAYAN_WORKER_A_MAX_MEMORY_PER_CHILD = 500000
MAYAN_WORKER_A_MAX_TASKS_PER_CHILD = 4000
MAYAN_WORKER_A_NICE_LEVEL = 0
MAYAN_WORKER_B_CONCURRENCY = 4
MAYAN_WORKER_B_MAX_MEMORY_PER_CHILD = 500000
MAYAN_WORKER_B_MAX_TASKS_PER_CHILD = 4000
MAYAN_WORKER_B_NICE_LEVEL = 2
MAYAN_WORKER_C_CONCURRENCY = 4
MAYAN_WORKER_C_MAX_MEMORY_PER_CHILD = 500000
MAYAN_WORKER_C_MAX_TASKS_PER_CHILD = 1000
MAYAN_WORKER_C_NICE_LEVEL = 10
MAYAN_WORKER_D_CONCURRENCY = 1
MAYAN_WORKER_D_MAX_MEMORY_PER_CHILD = 500000
MAYAN_WORKER_D_MAX_TASKS_PER_CHILD = 500
MAYAN_WORKER_D_NICE_LEVEL = 15
MAYAN_WORKER_E_CONCURRENCY = 4
MAYAN_WORKER_E_MAX_MEMORY_PER_CHILD = 500000
MAYAN_WORKER_E_MAX_TASKS_PER_CHILD = 20000
MAYAN_WORKER_E_NICE_LEVEL = 2
