from mayan.apps.dependencies.classes import PythonDependency

PythonDependency(
    module=__name__, name='django-stronghold', version_string='==0.4.0'
)
PythonDependency(
    module=__name__, name='furl', version_string='==2.1.4'
)
