from mayan.apps.icons.icons import Icon

icon_source_column_help_text = Icon(
    driver_name='fontawesome', symbol='question'
)
icon_source_column_help_text = Icon(
    driver_name='fontawesome-css', css_classes='far fa-question-circle'
)
