{% load i18n %}

{% load common_tags %}

{% common_project_information '__title__' as project_title %}

{% if autoadmin_properties.account %}
    <div class="row">
        <div class="col-xs-12 col-sm-10 col-sm-offset-1 col-md-10 col-md-offset-1 col-lg-6 col-lg-offset-3">
            <br>
            <div class="panel panel-primary">
                <div class="panel-heading">
                    <h3 class="text-center panel-title">{% trans 'Automatic credentials' %}</h3>
                </div>
                <div class="panel-body">
                    <div class="content login">
                        <p class="text-center">{% blocktrans %}You have just finished installing <strong>{{ project_title }}</strong>, congratulations!{% endblocktrans %}</p>
                        <p class="text-center">{% trans 'Login using the following credentials:' %}</p>
                        <p class="text-center">
                            {% blocktrans with autoadmin_properties.account as account %}Username: <strong>{{ account }}</strong>{% endblocktrans %}<br>
                            {% blocktrans with autoadmin_properties.account.email as email %}Email: <strong>{{ email }}</strong>{% endblocktrans %}<br>
                            {% blocktrans with autoadmin_properties.password as password %}Password: <strong>{{ password }}</strong>{% endblocktrans %}
                        </p>
                        <p class="text-center">{% trans 'Be sure to change the password to increase security and to disable this message.' %}</p>
                    </div>
                </div>
            </div>
        </div>
    </div>
{% endif %}
