{% load static %}

<link href="{% static 'appearance_bootstrap/node_modules/bootswatch/flatly/bootstrap.min.css' %}" media="screen" rel="stylesheet" type="text/css" />

<link href="{% static 'appearance_bootstrap/css/appearance_bootstrap.css' %}" media="screen" rel="stylesheet" type="text/css" />

{# Call the general appearance CSS after bootstrap.css to allow final overwrites of styles #}
<link href="{% static 'appearance/css/appearance.css' %}" media="screen" rel="stylesheet" type="text/css" />
