from mayan.apps.icons.icons import Icon

icon_user_locale_profile_detail = Icon(
    driver_name='fontawesome', symbol='globe'
)
icon_user_locale_profile_edit = Icon(
    driver_name='fontawesome-dual', primary_symbol='globe',
    secondary_symbol='pencil-alt'
)
