from mayan.apps.icons.icons import Icon

icon_quota_backend_selection = Icon(
    driver_name='fontawesome-dual', primary_symbol='tachometer-alt',
    secondary_symbol='plus'
)
icon_quota_create = Icon(
    driver_name='fontawesome-dual', primary_symbol='tachometer-alt',
    secondary_symbol='plus'
)
icon_quota_delete = Icon(driver_name='fontawesome', symbol='times')
icon_quota_edit = Icon(driver_name='fontawesome', symbol='pencil-alt')
icon_quota_list = Icon(driver_name='fontawesome', symbol='tachometer-alt')
icon_quota_setup = Icon(driver_name='fontawesome', symbol='tachometer-alt')
