<textarea class="appearance-overscroll-contain appearance-resize-vertical form-control templating-widget-code appearance-resize-persist appearance-form-control-copy" data-linked-id="id_template_preview" name="{{ widget.name }}"{% include "django/forms/widgets/attrs.html"%}>
{% if widget.value %}{{ widget.value }}{% endif %}</textarea>

<pre class="appearance-resize-vertical appearance-overscroll-contain appearance-resize-persist" data-height-original="200px" id="id_template_preview"><code class="language-django templating-widget-code"></code></pre>
