<span class="fa-layers fa-fw {{ css_classes }} mayan-icon">
    {% if enable_shadow %}
        {% for entry in data %}
            <i class="{{ entry.class }} fashadow" data-fa-transform="{{ entry.transform }}" data-fa-mask="{{ entry.mask }}"></i>
        {% endfor %}
    {% endif %}
    {% for entry in data %}
        <i class="{{ entry.class }}" data-fa-transform="{{ entry.transform }}" data-fa-mask="{{ entry.mask }}"></i>
    {% endfor %}
</span>
