from mayan.apps.icons.icons import Icon

icon_asset_create = Icon(driver_name='fontawesome', symbol='save')
icon_asset_delete_multiple = Icon(driver_name='fontawesome', symbol='times')
icon_asset_delete_single = icon_asset_delete_multiple
icon_asset_detail = Icon(driver_name='fontawesome', symbol='save')
icon_asset_edit = Icon(driver_name='fontawesome', symbol='pencil-alt')
icon_asset_list = Icon(driver_name='fontawesome', symbol='save')

icon_transformations = Icon(driver_name='fontawesome', symbol='crop')

icon_transformation_create = Icon(driver_name='fontawesome', symbol='plus')
icon_transformation_delete = Icon(driver_name='fontawesome', symbol='times')
icon_transformation_edit = Icon(
    driver_name='fontawesome', symbol='pencil-alt'
)
icon_transformation_list = icon_transformations
icon_transformation_select = Icon(driver_name='fontawesome', symbol='plus')

icon_layer_decorations = Icon(
    driver_name='fontawesome', symbol='paint-roller'
)
icon_layer_transformation = Icon(
    driver_name='fontawesome', symbol='crop'
)
