{% load i18n %}

{% spaceless %}
<div class="text-center" style="border: height: 100%;">
    <div class="fa-4x" data-toggle="tooltip" data-placement="bottom" title="{% trans 'No file pages' %}">
        <span class="fa-layers fa-fw">
            <i class="far fa-file text-primary" data-fa-transform="down-4"></i>
            <span class="fa-stack" data-fa-transform="shrink-8 up-5 left-10">
              <i class="fas fa-copy" data-fa-transform="shrink-10 up-2 left-10"></i>
              <i class="fas fa-ban text-danger" data-fa-transform="shrink-7 up-2 left-10"></i>
            </span>
        </span>
    </div>
</div>
{% endspaceless %}
