{% load i18n %}
{% load static %}

{% load common_tags %}
{% load navigation_tags %}
{% load smart_settings_tags %}

<div class="row">
    <div class="col-xs-12">
        {% include 'appearance/partials/list/header.html' %}
        {% if not object_list %}
            <div class="well">
                {% include 'appearance/partials/list/no_results.html' %}
            </div>
        {% else %}
            {% navigation_resolve_menu name='multi item' sort_results=True source=object_list.0 as links_multi_menus_results %}

            {% navigation_get_source_columns source=object_list only_identifier=True as source_columns_identifier %}
            {% navigation_get_source_columns source=object_list exclude_identifier=True as source_columns_non_identifier %}

            <div class="well center-block">
                <div class="row row-items">
                    {% for object in object_list %}
                        {% include 'appearance/partials/list/panel/single.html' %}
                    {% endfor %}
                </div>
            </div>
        {% endif %}
    </div>
</div>

<script>
    'use strict';

    $(function() {
        $('.row-items > [class*="col"] .panel-item .panel-heading').matchHeight();
        $('.row-items > [class*="col"] .panel-item .panel-body').matchHeight();
        $('.row-items > [class*="col"] .panel-item').matchHeight();
    });
</script>
