{% load icons_tags %}
{% load navigation_tags %}

{% navigation_link_get_icon link=link as link_icon %}

<div class="{{ div_class }}">
    <a class="btn btn-primary btn-lg navigation-btn-lg {% if 'new_window' in link.tags %}new_window{% endif %}" href="{{ link.url }}">
        {% if link_icon %}<span class="navigation-lg-icon-container">{% icons_icon_render link_icon enable_shadow=True %}</span>{% endif %}
        <br>
        {{ link.text }}
    </a>
</div>
