COMMENT_APP_TEMPLATE_CACHE_DISABLE = '{# appearance_app_template_nocache #}'

COMMAND_NAME_APPEARANCE_PREPARE_STATIC = 'appearance_prepare_static'

DEFAULT_APPEARANCE_ELIDED_PAGER_ON_EACH_SIDE = 3
DEFAULT_APPEARANCE_ELIDED_PAGER_ON_ENDS = 1

DEFAULT_APPEARANCE_PAGINATION_DROPDOWN_ENABLE = False
DEFAULT_APPEARANCE_PAGINATION_DROPDOWN_RANGE = 100
DEFAULT_APPEARANCE_PAGINATION_INPUT_ENABLE = False

DEFAULT_AJAX_REDIRECTION_CODE = 278
DEFAULT_MAXIMUM_TITLE_LENGTH = 120
DEFAULT_MESSAGE_POSITION = 'bottom-right'
DEFAULT_MENU_POLLING_INTERVAL = 5000
DEFAULT_THROTTLING_MAXIMUM_REQUESTS = 5
DEFAULT_THROTTLING_TIMEOUT = 4000
