from mayan.apps.icons.icons import Icon

icon_color_random = Icon(driver_name='fontawesome', symbol='random')

icon_dropzone_fail = Icon(driver_name='fontawesome', symbol='times-circle')
icon_dropzone_file = Icon(
    driver_name='fontawesome-css', css_classes='far fa-file fa-10x'
)
icon_dropzone_ok = Icon(driver_name='fontawesome', symbol='check-circle')
icon_dropzone_upload = Icon(
    driver_name='fontawesome', symbol='cloud-upload-alt'
)

icon_fail = Icon(driver_name='fontawesome', symbol='times')
icon_ok = Icon(driver_name='fontawesome', symbol='check')
