from mayan.apps.icons.icons import Icon

# App

icon_file_caching = Icon(
    driver_name='fontawesome', symbol='warehouse'
)

# Cache
icon_cache_detail = Icon(
    driver_name='fontawesome', symbol='warehouse'
)
icon_cache_list = Icon(
    driver_name='fontawesome', symbol='warehouse'
)
icon_cache_purge_multiple = Icon(
    driver_name='fontawesome-dual', primary_symbol='warehouse',
    secondary_symbol='check'
)
icon_cache_purge_single = icon_cache_purge_multiple

# Cache partition

icon_cache_partition_detail = Icon(
    driver_name='fontawesome', symbol='warehouse'
)
icon_cache_partition_purge = Icon(
    driver_name='fontawesome-dual', primary_symbol='warehouse',
    secondary_symbol='check'
)
