from mayan.apps.dependencies.classes import PythonDependency

PythonDependency(
    module=__name__, name='gevent', version_string='==25.8.2'
)
PythonDependency(
    module=__name__, name='greenlet', version_string='==3.2.4'
)
PythonDependency(
    module=__name__, name='gunicorn', version_string='==23.0.0'
)
PythonDependency(
    module=__name__, name='whitenoise', version_string='==6.9.0'
)
