{% load navigation_tags %}

<div class="panel-heading">
    <div class="form-group">
        <div class="checkbox">
            <label for="id_indexes_0" style="cursor: auto;">
                {% if links_multi_menus_results and not hide_multi_item_actions %}
                    <input class="form-multi-object-action-checkbox check-all-slave checkbox" name="pk_{{ object.pk }}" style="cursor: pointer;" type="checkbox" />
                {% endif %}

                <span style="color: white; word-break: break-all; overflow-wrap: break-word;">
                    {% if not hide_object %}
                        {% if not hide_link %}
                            <a href="{{ object.get_absolute_url }}">{{ object }}</a>
                        {% else %}
                            {{ object }}
                        {% endif %}
                    {% else %}
                        {% navigation_source_column_resolve column=source_columns_identifier.0 as column_value %}
                        {{ column_value }}
                    {% endif %}
                </span>
            </label>
        </div>
    </div>
</div>
