{% load static %}

<script src="{% static 'converter/js/mayan_image.js' %}" type="text/javascript"></script>

<script>
    jQuery(document).ready(function() {
        MayanImage.setup(app);
    });
</script>
