from mayan.apps.icons.icons import Icon

icon_download_file_delete = Icon(
    driver_name='fontawesome', symbol='times'
)
icon_download_file_download = Icon(
    driver_name='fontawesome', symbol='download'
)
icon_download_file_list = Icon(
    driver_name='fontawesome-dual', primary_symbol='server',
    secondary_symbol='arrow-down'
)
