<script>
    'use strict';

    jQuery(document).ready(function() {
        $('body').on('change', '#navigation-form-sort-field', function (event) {
            const $this = $(this);

            let url = new URL(
                window.location.hash.substring(1), window.location
            )
            url.search = $this.serializeArray()[0].value;

            partialNavigation.setLocation(url.pathname + url.search);
        });
    });
</script>
