from mayan.apps.icons.icons import Icon

icon_signature_captures = Icon(
    driver_name='fontawesome', symbol='file-contract'
)
icon_signature_capture_create = Icon(
    driver_name='fontawesome-dual', primary_symbol='file-contract',
    secondary_symbol='plus'
)
icon_signature_capture_single_delete = Icon(
    driver_name='fontawesome', symbol='times'
)
icon_signature_capture_edit = Icon(
    driver_name='fontawesome', symbol='pencil-alt'
)
icon_signature_capture_list = Icon(
    driver_name='fontawesome', symbol='file-contract'
)
