{% load i18n %}

{% load common_tags %}

{# appearance_app_template_nocache #}

{% common_get_missing_items as missing_items %}

{% if missing_items %}
    <div class="alert alert-warning">
        {% for item in missing_items %}
            <p><strong>{{ item.label }}</strong> </p>
            <p>
                {{ item.description }}
                {% if item.view %}<a class="btn btn-primary btn-xs" href="{% url item.view %}">{% trans 'Click here to fix this.' %}</a>{% endif %}
            </p>
    {% endfor %}
    </div>
{% endif %}
